@@ -6,7 +6,7 @@ import importlib
 from typing import Dict, List, Iterable, Union, Iterator
 from jc import appdirs
 
-__version__ = '1.18.8'
+__version__ = '1.19.0'
 
 parsers = [
     'acpi',
@@ -16,6 +16,7 @@ parsers = [
     'asciitable',
     'asciitable-m',
     'blkid',
+    'chage',
     'cksum',
     'crontab',
     'crontab-u',
@@ -34,6 +35,7 @@ parsers = [
     'free',
     'fstab',
     'git-log',
+    'git-log-s',
     'group',
     'gshadow',
     'hash',
